@@ -1,5 +1,5 @@
-'Useful functions and classes for PyGame'
-__version__ = '1.6.2'
+'Useful functions and classes for pygame'
+__version__ = '1.8.2'
 _failed_imports = []
 
 try:
@@ -13,7 +13,7 @@ except ImportError as e:
 	_failed_imports.append(e.name)
 
 try:
-	from .animations import *
+	from .animations import Animations
 except ImportError as e:
 	_failed_imports.append(e.name)
 
