@@ -14,15 +14,15 @@ class Animations:
 
 	action
 
-	animation_frames
+	frames
 
-	animations_data
+	data
 
 	frame'''
 	def __init__(self, action=None):
 		'Initialising an Animations class'
-		self.animations_data = {}
-		self.animation_frames = {}
+		self.data = {}
+		self.frames = {}
 		self.action = action
 		self.frame = 0
 
@@ -51,55 +51,53 @@ class Animations:
 
 		frame_durations is a list or tuple with how long each frame should last, it has to be in order
 		repeat is if the animation should loop, if it is False, the image would stay on the last one
-		The images will be added to animation_frames'''
+		The images will be added to frames'''
 		path = Path(path).resolve()
 		if not path.is_dir():
 			raise FileNotFoundError(_ENOENT, _strerror(_ENOENT), f'{path}')
 		animation_name = path.name if animation_name is None else animation_name
-		self.animations_data[animation_name] = [[], repeat, 0]
+		self.data[animation_name] = {'durations': [], 'repeat': repeat, 'full': 0}
 		if not file_type:
 			file_type = most_used([file.suffix for file in path.iterdir() if file.is_file()])[0]
 		for i, frame_duration in enumerate(frame_durations):
 			if not path.joinpath(f'{path.name}{i + 1}{file_type}').is_file():
-				raise pygame.error(f'Too many non image files in \'{path}\' or the image file is not named \'{path.name}{i + 1}{file_type}\'')
-			animation_frame_id = f'{animation_name}{i + 1}'
-			self.animation_frames[animation_frame_id] = load_image(path.joinpath(f'{path.name}{i + 1}{file_type}'), colourkey, alpha, convert_alpha)
-			self.animations_data[animation_name][0].append((animation_frame_id, frame_duration))
-			self.animations_data[animation_name][2] += frame_duration
+				raise pygame.error(f'too many non image files in \'{path}\' or the image file is not named \'{path.name}{i + 1}{file_type}\'')
+			frame_id = f'{animation_name}{i + 1}'
+			self.frames[frame_id] = load_image(path.joinpath(f'{path.name}{i + 1}{file_type}'), colourkey, alpha, convert_alpha)
+			self.data[animation_name]['durations'].append({'id': frame_id, 'duration': frame_duration})
+			self.data[animation_name]['full'] += frame_duration
 
 	def add_image(self, image, animation_name, duration, repeat=True):
 		'''Manually add an image to an animation
 		If the animation_name does not yes exist, it will be created
-		The image will be added to animation_frames with a number, so it has to be added in the correct order'''
-		if animation_name not in self.animations_data:
-			self.animations_data[animation_name] = [[], repeat, 0]
-		animation_frame_id = f'{animation_name}{len(self.animations_data[animation_name][0]) + 1}'
-		self.animation_frames[animation_frame_id] = image.copy()
-		self.animations_data[animation_name][0].append((animation_frame_id, duration))
-		self.animations_data[animation_name][2] += duration
+		The image will be added to frames with a number, so it has to be added in the correct order'''
+		if animation_name not in self.data:
+			self.data[animation_name] = {'durations': [], 'repeat': repeat, 'full': 0}
+		frame_id = f'{animation_name}{len(self.data[animation_name]["durations"]) + 1}'
+		self.frames[frame_id] = image.copy()
+		self.data[animation_name]['durations'].append({'id': frame_id, 'duration': duration})
+		self.data[animation_name]['full'] += duration
 
 	def current_image(self, delta_time=1):
 		'''Get the current image in the animation
 		delta_time is how much the frame should update, usually it would be 1
 
 		Returns: pygame.Surface'''
-		if self.action not in self.animations_data:
-			raise KeyError(f'Animation \'{self.action}\' is not defined')
-		animation_data = self.animations_data[self.action]
+		if self.action not in self.data:
+			raise KeyError(f'action \'{self.action}\' is not defined')
+		animation_data = self.data[self.action]
 		self.frame += delta_time
-		reset_frame = round(self.frame) > animation_data[2]
-		if reset_frame and animation_data[1]:
-			self.frame = 0
-		elif reset_frame and not animation_data[1]:
-			self.frame = animation_data[2]
-		for i, frame_data in enumerate(animation_data[0]):
-			if round(self.frame) <= sum([frame_duration[1] for frame_duration in animation_data[0]][:i + 1]):
-				return self.animation_frames[frame_data[0]]
+		reset_frame = round(self.frame) > animation_data['full']
+		if reset_frame:
+			self.frame = animation_data['full'] if not animation_data['repeat'] else 0
+		for i, frame_data in enumerate(animation_data['durations']):
+			if round(self.frame) <= sum([frame_duration['duration'] for frame_duration in animation_data['durations']][:i + 1]): #SUM EVERY FRAME DURATION OF ALL THE FRAMES BEFORE I TO CHECK WHAT THE CURRENT FRAME IT IS
+				return self.frames[frame_data['id']]
 
 	def set_action(self, action):
 		'Set the current action, the frame will also be reset to 0'
-		if action not in self.animations_data:
-			raise KeyError(f'Animation \'{action}\' is not defined')
+		if action not in self.data:
+			raise KeyError(f'action \'{action}\' is not defined')
 		if self.action != action:
 			self.action = action
 			self.frame = 0
\ No newline at end of file
