@@ -1,7 +1,8 @@
 'A Circle class with collision functions'
 import pygame
+from ..core import int_location
 from importlib import import_module
-poly =  import_module('.polygon', __package__)
+poly = import_module('.polygon', __package__)
 
 class Circle:
 	'''A circle to check collisions with and render
@@ -74,7 +75,7 @@ class Circle:
 		Returns: bool'''
 		if not isinstance(circle, Circle):
 			raise TypeError('circle is not a Circle object')
-		offset = circle.location - self.location
+		offset = int_location(circle.location - self.location)
 		return bool(self.mask.overlap(circle.mask, offset))
 
 	def collidelist(self, circles):
@@ -88,7 +89,6 @@ class Circle:
 		for i, circle in enumerate(circles):
 			if self.collide(circle):
 				return i
-		return None
 
 	def colliderect(self, Rect):
 		'''A function to check if the Circle collides with a pygame.Rect object
@@ -96,7 +96,7 @@ class Circle:
 		Returns: bool'''
 		if not isinstance(Rect, pygame.Rect):
 			raise TypeError('Rect is not a pygame.Rect object')
-		offset = Rect.topleft - self.location
+		offset = int_location(Rect.topleft - self.location)
 		rect_mask = pygame.Mask(Rect.size, True)
 		return bool(self.mask.overlap(rect_mask, offset))
 
@@ -106,7 +106,7 @@ class Circle:
 		Returns: bool'''
 		if not isinstance(polygon, poly.Polygon):
 			raise TypeError('polygon is not a Polygon object')
-		offset = polygon.location - self.location
+		offset = int_location(polygon.location - self.location)
 		return bool(self.mask.overlap(polygon.mask, offset))
 
 	def render(self, surface, scroll=pygame.Vector2(), width=0):
