@@ -1,6 +1,8 @@
 '''A class to make the dipslay/screen
 It also has functions to enter and exit fullscreen'''
 import pygame
+from os import name as _name
+from .core import round_location
 from pygame._sdl2.video import Window
 
 class Screen:
@@ -28,10 +30,14 @@ class Screen:
 	vsync
 
 	window'''
-	def __init__(self, size, flags=pygame.SCALED, depth=0, display=0, vsync=1, fullscreen=False):
+	def __init__(self, size, flags=pygame.SCALED, depth=0, display=0, vsync=1 if _name != 'nt' else 0, fullscreen=False):
 		'Initialising the class, it should only be done once'
+		if type(fullscreen) is not bool:
+			raise TypeError('fullscreen must be a bool')
+		if not all(type(variable) is int for variable in (flags, depth, display, vsync)):
+			raise TypeError('flags, depth, display and vsync must be an int (a display flag is an integer)')
 		self.fullscreen_size = (pygame.display.Info().current_w, pygame.display.Info().current_h)
-		self.size = list(size)
+		self.size = round_location(size)
 		self.flags = flags
 		self.depth = depth
 		self.display = display
@@ -40,7 +46,7 @@ class Screen:
 		if fullscreen:
 			self.toggle_fullscreen(manual=fullscreen)
 		else:
-			self.pygame_display = pygame.display.set_mode(size, flags, depth, display, vsync)
+			self.pygame_display = pygame.display.set_mode(self.size, flags, depth, display, vsync)
 		self.window = Window.from_display_module()
 
 	def __repr__(self):
@@ -55,9 +61,9 @@ class Screen:
 		Than manual has to be True (enter fullscreen) or False (exit Fullscreen)
 
 		Returns: pygame.Surface'''
-		self.fullscreen = not self.fullscreen
-		if manual is not None:
-			self.fullscreen = bool(manual)
+		if manual is not None and type(manual) is not bool:
+			raise TypeError('manual must be a bool')
+		self.fullscreen = not self.fullscreen if manual is None else manual
 		if self.fullscreen:
 			self.pygame_display = pygame.display.set_mode(self.size, pygame.SCALED | pygame.NOFRAME | pygame.FULLSCREEN, self.depth, self.display, self.vsync)
 		else:
