@@ -1,6 +1,8 @@
 'Visual effects classes and functions for pgeng'
 from .. import _failed_imports
 
+__all__ = ['circle_lighting', 'Particle', 'ShockWave']
+
 try:
     from .core import circle_lighting
 except ImportError as e:
@@ -8,6 +10,7 @@ except ImportError as e:
 
 try:
     from .flame import *
+    __all__ += flame.__all__
 except ImportError as e:
     _failed_imports.append(e.name)
 
@@ -23,5 +26,6 @@ except ImportError as e:
 
 try:
     from .spark import *
+    __all__ += spark.__all__
 except ImportError as e:
     _failed_imports.append(e.name)
\ No newline at end of file
